"use strict";

var logger = require('./../logger');

/**
 * Object representing information needed for constructing {@link CustomMap}
 * objects.
 */
function CustomMapOptions(params) {
  if (params.map === undefined) {
    throw new Error("map must be defined");
  }
  this.setMap(params.map);

  if (params.project === undefined) {
    throw new Error("project must be defined");
  }
  this.setProject(params.project);

  if (params.hideDiv !== undefined) {
    this._hideDiv = params.hideDiv;
  } else {
    this._hideDiv = null;
  }

  if (params.overviewDiv !== undefined) {
    this._overviewDiv = params.overviewDiv;
  } else {
    this._overviewDiv = null;
  }

  if (params.markerOptimization !== undefined) {
    if (typeof params.markerOptimization === "boolean") {
      this._markerOptimization = params.markerOptimization;
    } else {
      logger.warn("markerOptimization must be of type boolean");
      this._markerOptimization = true;
    }
  } else {
    this._markerOptimization = true;
  }

  if (params.bigLogo !== undefined) {
    if (typeof params.bigLogo === "boolean") {
      this._bigLogo = params.bigLogo;
    } else {
      logger.warn("bigLogo must be of type boolean");
      this._bigLogo = false;
    }
  } else {
    this._bigLogo = false;
  }

  if (params.customTouchInterface !== undefined) {
    if (typeof params.customTouchInterface === "boolean") {
      this._customTouchInterface = params.customTouchInterface;
    } else {
      logger.warn("customTouchInterface must be of type boolean");
      this._customTouchInterface = false;
    }
  } else {
    this._customTouchInterface = false;
  }

  this.setDebug(params.debug);
  this.setFitMapBounds(params.debug);
}

CustomMapOptions.prototype.getMap = function() {
  return this._map;
};

CustomMapOptions.prototype.isMarkerOptimization = function() {
  return this._markerOptimization;
};

CustomMapOptions.prototype.isBigLogo = function() {
  return this._bigLogo;
};
CustomMapOptions.prototype.isCustomTouchInterface = function() {
  return this._customTouchInterface;
};

CustomMapOptions.prototype.getOverviewDiv = function() {
  return this._overviewDiv;
};
CustomMapOptions.prototype.getProject = function() {
  return this._project;
};
CustomMapOptions.prototype.setProject = function(project) {
  this._project = project;
};
CustomMapOptions.prototype.getHideDiv = function() {
  return this._hideDiv;
};
CustomMapOptions.prototype.setDebug = function(debug) {
  if (debug !== undefined) {
    if (typeof debug !== "boolean") {
      logger.warn("Params must be boolean");
    }
    this._debug = debug;
  }
};

CustomMapOptions.prototype.setFitMapBounds = function(fitMapBounds) {
  this._fitMapBounds = fitMapBounds;
};

CustomMapOptions.prototype.getFitMapBounds = function() {
  return this._fitMapBounds;
};

CustomMapOptions.prototype.setMap = function(map) {
  this._map = map;
};

CustomMapOptions.prototype.getFitMapBounds = function() {
  return this._fitMapBounds;
};

CustomMapOptions.prototype.isDebug = function() {
  return this.debug === true;
};

module.exports = CustomMapOptions;
