"use strict";

/**
 * Class representing alias data.
 * 
 * @param javaObject
 *          object deserialized ajax query to the server side
 */
function Alias(javaObject) {
  if (javaObject.idObject !== undefined) {
    this.setId(javaObject.idObject);
  } else {
    this.setId(javaObject.id);
  }
  this.setModelId(javaObject.modelId);
  if (javaObject.bounds !== undefined) {
    this.setX(javaObject.bounds.x);
    this.setY(javaObject.bounds.y);
    this.setWidth(javaObject.bounds.width);
    this.setHeight(javaObject.bounds.height);
  }

  if (this._modelId === undefined) {
    throw new Error("ModelId is not defined for alias", javaObject);
  }

  if (javaObject.name === undefined) {
    this.setIsComplete(false);
  } else {
    this.update(javaObject);
  }
}

/**
 * Updates alias with full data information. This function should be called when
 * full informatin about alias is retrieved from server.
 * 
 * @param javaObject
 *          object representing data from server side
 */
Alias.prototype.update = function(javaObject) {
  if (javaObject.name === undefined) {
    return;
  }
  this.description = javaObject.notes;
  this.type = javaObject.type;
  this.symbol = javaObject.symbol;
  this.fullName = javaObject.fullName;
  this.abbreviation = javaObject.abbreviation;
  this.formula = javaObject.formula;
  this.name = javaObject.name;
  this.synonyms = javaObject.synonyms;
  this.formerSymbols = javaObject.formerSymbols;
  this.references = javaObject.references;
  this.other = javaObject.other;
  this.setIsComplete(true);
};

/**
 * Returns identifier of the alias.
 * 
 * @returns identifier of the alias
 */
Alias.prototype.getId = function() {
  return this.id;
};

Alias.prototype.setId = function(id) {
  this.id = id;
};

/**
 * Returns model identifier where {@link Alias} is located.
 * 
 * @returns model identifier where {@link Alias} is located
 */
Alias.prototype.getModelId = function() {
  return this._modelId;
};

Alias.prototype.setModelId = function(modelId) {
  this._modelId = modelId;
};

Alias.prototype.getType = function() {
  return this.type;
};

Alias.prototype.getX = function() {
  return this.x;
};

Alias.prototype.setX = function(x) {
  this.x = x;
};

Alias.prototype.setY = function(y) {
  this.y = y;
};

Alias.prototype.setWidth = function(width) {
  this.width = width;
};

Alias.prototype.setHeight = function(height) {
  this.height = height;
};

Alias.prototype.getName = function() {
  return this.name;
};

Alias.prototype.setType = function(type) {
  this.type = type;
};

Alias.prototype.isComplete = function() {
  return this._complete;
};

Alias.prototype.setIsComplete = function(complete) {
  this._complete = complete;
};

module.exports = Alias;
